# iRedis

A Terminal Client for Redis with AutoCompletion and Syntax Highlighting.

## Install

```
pip install iredis
```

## Usage

```
$ iredis -h
```

## Features

- <kbd>Ctrl</kbd> + <kbd>C</kbd> to clear cureent line, won't exit redis-cli. Use <kbd>Ctrl</kbd> + <kbd>D</kbd>  
- Say "Goodbye!" to you when you exit!
